import { Objectish, Drafted, AnyObject, AnyArray, AnyMap, AnySet, ImmerState, Archtype } from "./types";
/** Use a class type for `nothing` so its type is unique */
export declare class Nothing {
    private _;
}
export declare const hasMap: boolean;
export declare const hasSet: boolean;
/**
 * The sentinel value returned by producers to replace the draft with undefined.
 */
export declare const NOTHING: Nothing;
/**
 * To let Immer treat your class instances as plain immutable objects
 * (albeit with a custom prototype), you must define either an instance property
 * or a static property on each of your custom classes.
 *
 * Otherwise, your class instance will never be drafted, which means it won't be
 * safe to mutate in a produce callback.
 */
export declare const DRAFTABLE: unique symbol;
export declare const DRAFT_STATE: unique symbol;
export declare const iteratorSymbol: typeof Symbol.iterator;
/** Returns true if the given value is an Immer draft */
export declare function isDraft(value: any): boolean;
/** Returns true if the given value can be drafted by Immer */
export declare function isDraftable(value: any): boolean;
export declare function isPlainObject(value: any): boolean;
/** Get the underlying object that is represented by the given draft */
export declare function original<T>(value: Drafted<T>): T | undefined;
export declare const ownKeys: (target: AnyObject) => PropertyKey[];
export declare function each<T extends Objectish>(obj: T, iter: (key: string | number, value: any, source: T) => void): void;
export declare function isEnumerable(base: AnyObject, prop: PropertyKey): boolean;
export declare function getArchtype(thing: any): Archtype;
export declare function has(thing: any, prop: PropertyKey): boolean;
export declare function get(thing: AnyMap | AnyObject, prop: PropertyKey): any;
export declare function set(thing: any, propOrOldValue: PropertyKey, value: any): void;
export declare function is(x: any, y: any): boolean;
export declare function isMap(target: any): target is AnyMap;
export declare function isSet(target: any): target is AnySet;
export declare function latest(state: ImmerState): any;
export declare function shallowCopy<T extends AnyObject | AnyArray>(base: T, invokeGetters?: boolean): T;
export declare function freeze(obj: any, deep: boolean): void;
export declare function createHiddenProperty(target: AnyObject, prop: PropertyKey, value: any): void;
export declare function die(): never;
//# sourceMappingURL=common.d.ts.map